@@ -15,18 +15,15 @@
 
 #include <mlpack/prereqs.hpp>
 
-namespace mlpack {
-namespace ann /** Artificial Neural Network. */ {
+#include "layer.hpp"
 
+namespace mlpack {
 
 /**
  * The dropout layer is a regularizer that randomly with probability 'ratio'
  * sets input values to zero and scales the remaining elements by factor 1 /
  * (1 - ratio) rather than during test time so as to keep the expected sum same.
- * In the deterministic mode (during testing), there is no change in the input.
- *
- * Note: During training you should set deterministic to false and during
- * testing you should set deterministic to true.
+ * When the layer is in testing mode, there is no change in the input.
  *
  * For more information, see the following.
  *
@@ -43,14 +40,11 @@ namespace ann /** Artificial Neural Network. */ {
  * }
  * @endcode
  *
- * @tparam InputDataType Type of the input data (arma::colvec, arma::mat,
- *         arma::sp_mat or arma::cube).
- * @tparam OutputDataType Type of the output data (arma::colvec, arma::mat,
- *         arma::sp_mat or arma::cube).
+ * @tparam MatType Matrix representation to accept as input and use for
+ *    computation.
  */
-template<typename InputDataType = arma::mat,
-         typename OutputDataType = arma::mat>
-class Dropout
+template<typename MatType = arma::mat>
+class DropoutType : public Layer<MatType>
 {
  public:
   /**
@@ -58,7 +52,22 @@ class Dropout
    *
    * @param ratio The probability of setting a value to zero.
    */
-  Dropout(const double ratio = 0.5);
+  DropoutType(const double ratio = 0.5);
+
+  //! Clone the DropoutType object. This handles polymorphism correctly.
+  DropoutType* Clone() const { return new DropoutType(*this); }
+
+  // Virtual destructor.
+  virtual ~DropoutType() { }
+
+  //! Copy the given DropoutType.
+  DropoutType(const DropoutType& other);
+  //! Take ownership of the given DropoutType.
+  DropoutType(DropoutType&& other);
+  //! Copy the given DropoutType.
+  DropoutType& operator=(const DropoutType& other);
+  //! Take ownership of the given DropoutType.
+  DropoutType& operator=(DropoutType&& other);
 
   /**
    * Ordinary feed forward pass of the dropout layer.
@@ -66,8 +75,7 @@ class Dropout
    * @param input Input data used for evaluating the specified function.
    * @param output Resulting output activation.
    */
-  template<typename eT>
-  void Forward(const arma::Mat<eT>& input, arma::Mat<eT>& output);
+  void Forward(const MatType& input, MatType& output);
 
   /**
    * Ordinary feed backward pass of the dropout layer.
@@ -76,25 +84,7 @@ class Dropout
    * @param gy The backpropagated error.
    * @param g The calculated gradient.
    */
-  template<typename eT>
-  void Backward(const arma::Mat<eT>& /* input */,
-                const arma::Mat<eT>& gy,
-                arma::Mat<eT>& g);
-
-  //! Get the output parameter.
-  OutputDataType const& OutputParameter() const { return outputParameter; }
-  //! Modify the output parameter.
-  OutputDataType& OutputParameter() { return outputParameter; }
-
-  //! Get the detla.
-  OutputDataType const& Delta() const { return delta; }
-  //! Modify the delta.
-  OutputDataType& Delta() { return delta; }
-
-  //! The value of the deterministic parameter.
-  bool Deterministic() const { return deterministic; }
-  //! Modify the value of the deterministic parameter.
-  bool& Deterministic() { return deterministic; }
+  void Backward(const MatType& /* input */, const MatType& gy, MatType& g);
 
   //! The probability of setting a value to zero.
   double Ratio() const { return ratio; }
@@ -110,29 +100,24 @@ class Dropout
    * Serialize the layer.
    */
   template<typename Archive>
-  void serialize(Archive& ar, const unsigned int /* version */);
+  void serialize(Archive& ar, const uint32_t /* version */);
 
  private:
-  //! Locally-stored delta object.
-  OutputDataType delta;
-
-  //! Locally-stored output parameter object.
-  OutputDataType outputParameter;
-
-  //! Locally-stored mast object.
-  OutputDataType mask;
+  //! Locally-stored mask object.
+  MatType mask;
 
   //! The probability of setting a value to zero.
   double ratio;
 
   //! The scale fraction.
   double scale;
+}; // class DropoutType
 
-  //! If true dropout and scaling is disabled, see notes above.
-  bool deterministic;
-}; // class Dropout
+// Convenience typedefs.
+
+// Standard Dropout layer.
+typedef DropoutType<arma::mat> Dropout;
 
-} // namespace ann
 } // namespace mlpack
 
 // Include implementation.
