@@ -22,8 +22,11 @@
 #include "layer/alpha_dropout.cpp"
 #include "layer/batch_norm.cpp"
 #include "layer/convolution.cpp"
+#include "layer/concat.cpp"
+#include "layer/concatenate.cpp"
 #include "layer/dropout.cpp"
 #include "layer/grouped_convolution.cpp"
+#include "layer/hard_tanh.cpp"
 #include "layer/identity.cpp"
 #include "layer/linear3d.cpp"
 #include "layer/linear_no_bias.cpp"
@@ -31,4 +34,6 @@
 #include "layer/max_pooling.cpp"
 #include "layer/mean_pooling.cpp"
 #include "layer/padding.cpp"
+#include "layer/parametric_relu.cpp"
 #include "layer/softmax.cpp"
+#include "layer/softmin.cpp"
