@@ -11,7 +11,7 @@
  */
 
 #include <mlpack/core.hpp>
-#include "serialization_catch.hpp"
+#include "serialization.hpp"
 #include "test_catch_tools.hpp"
 #include "catch.hpp"
 
@@ -30,10 +30,8 @@ TEST_CASE("LoadInvalidExtensionFile", "[ImageLoadTest]")
   arma::Mat<unsigned char> matrix;
   data::ImageInfo info;
 
-  Log::Fatal.ignoreInput = true;
   REQUIRE_THROWS_AS(data::Load("invalidExtendion.p4ng", matrix, info,
       true),  std::runtime_error);
-  Log::Fatal.ignoreInput = false;
 }
 
 /**
@@ -85,10 +83,8 @@ TEST_CASE("SaveImageWrongInfo", "[ImageLoadTest]")
 
   arma::Mat<unsigned char> im1;
   im1 = arma::randi<arma::Mat<unsigned char>>(24 * 25 * 7, 1);
-  Log::Fatal.ignoreInput = true;
   REQUIRE_THROWS_AS(data::Save("APITest.bmp", im1, info, false),
       std::runtime_error);
-  Log::Fatal.ignoreInput = false;
 }
 
 /**
@@ -138,18 +134,18 @@ TEST_CASE("SaveImageMatAPITest", "[ImageLoadTest]")
 TEST_CASE("ImageInfoSerialization", "[ImageLoadTest]")
 {
   data::ImageInfo info(5, 5, 3, 90);
-  data::ImageInfo xmlInfo, textInfo, binaryInfo;
+  data::ImageInfo xmlInfo, jsonInfo, binaryInfo;
 
-  SerializeObjectAll(info, xmlInfo, textInfo, binaryInfo);
+  SerializeObjectAll(info, xmlInfo, jsonInfo, binaryInfo);
 
   REQUIRE(info.Width() == xmlInfo.Width());
   REQUIRE(info.Height() == xmlInfo.Height());
   REQUIRE(info.Channels() == xmlInfo.Channels());
   REQUIRE(info.Quality() == xmlInfo.Quality());
-  REQUIRE(info.Width() == textInfo.Width());
-  REQUIRE(info.Height() == textInfo.Height());
-  REQUIRE(info.Channels() == textInfo.Channels());
-  REQUIRE(info.Quality() == textInfo.Quality());
+  REQUIRE(info.Width() == jsonInfo.Width());
+  REQUIRE(info.Height() == jsonInfo.Height());
+  REQUIRE(info.Channels() == jsonInfo.Channels());
+  REQUIRE(info.Quality() == jsonInfo.Quality());
   REQUIRE(info.Width() == binaryInfo.Width());
   REQUIRE(info.Height() == binaryInfo.Height());
   REQUIRE(info.Channels() == binaryInfo.Channels());
