@@ -2,7 +2,7 @@
  * @file tests/main_tests/softmax_regression_test.cpp
  * @author Manish Kumar
  *
- * Test mlpackMain() of softmax_regression_main.cpp.
+ * Test RUN_BINDING() of softmax_regression_main.cpp.
  *
  * mlpack is free software; you may redistribute it and/or modify it under the
  * terms of the 3-clause BSD license.  You should have received a copy of the
@@ -12,33 +12,17 @@
 #define BINDING_TYPE BINDING_TYPE_TEST
 
 #include <mlpack/core.hpp>
-static const std::string testName = "SoftmaxRegression";
-
-#include <mlpack/core/util/mlpack_main.hpp>
 #include <mlpack/methods/softmax_regression/softmax_regression_main.cpp>
-#include "test_helper.hpp"
+#include <mlpack/core/util/mlpack_main.hpp>
+
+#include "main_test_fixture.hpp"
 
 #include "../test_catch_tools.hpp"
 #include "../catch.hpp"
 
 using namespace mlpack;
 
-struct SoftmaxRegressionTestFixture
-{
- public:
-  SoftmaxRegressionTestFixture()
-  {
-    // Cache in the options for this program.
-    IO::RestoreSettings(testName);
-  }
-
-  ~SoftmaxRegressionTestFixture()
-  {
-    // Clear the settings.
-    bindings::tests::CleanMemory();
-    IO::ClearSettings();
-  }
-};
+BINDING_TEST_FIXTURE(SoftmaxRegressionTestFixture);
 
 /**
  * Ensure that we get desired dimensions when both training
@@ -47,7 +31,7 @@ struct SoftmaxRegressionTestFixture
 TEST_CASE_METHOD(
     SoftmaxRegressionTestFixture,
     "SoftmaxRegressionOutputDimensionTest",
-    "[SoftmaxRegressionMainTest][BindingsTest]")
+    "[SoftmaxRegressionMainTest][BindingsTests]")
 {
   arma::mat inputData;
   if (!data::Load("trainSet.csv", inputData))
@@ -77,13 +61,13 @@ TEST_CASE_METHOD(
   // Input test data.
   SetInputParam("test", std::move(testData));
 
-  mlpackMain();
+  RUN_BINDING();
 
   // Check that number of output points are equal to number of input points.
-  REQUIRE(IO::GetParam<arma::Row<size_t>>("predictions").n_cols == testSize);
+  REQUIRE(params.Get<arma::Row<size_t>>("predictions").n_cols == testSize);
 
   // Check prediction have only single row.
-  REQUIRE(IO::GetParam<arma::Row<size_t>>("predictions").n_rows == 1);
+  REQUIRE(params.Get<arma::Row<size_t>>("predictions").n_rows == 1);
 }
 
 /**
@@ -92,7 +76,7 @@ TEST_CASE_METHOD(
 TEST_CASE_METHOD(
     SoftmaxRegressionTestFixture,
     "SoftmaxRegressionLabelsLessDimensionTest",
-    "[SoftmaxRegressionMainTest][BindingsTest]")
+    "[SoftmaxRegressionMainTest][BindingsTests]")
 {
   arma::mat inputData;
   if (!data::Load("trainSet.csv", inputData))
@@ -101,9 +85,7 @@ TEST_CASE_METHOD(
   // Input training data.
   SetInputParam("training", std::move(inputData));
 
-  Log::Fatal.ignoreInput = true;
-  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 }
 
 /**
@@ -112,7 +94,7 @@ TEST_CASE_METHOD(
 TEST_CASE_METHOD(
     SoftmaxRegressionTestFixture,
     "SoftmaxRegressionModelReuseTest",
-    "[SoftmaxRegressionMainTest][BindingsTest]")
+    "[SoftmaxRegressionMainTest][BindingsTests]")
 {
   arma::mat inputData;
   if (!data::Load("trainSet.csv", inputData))
@@ -142,32 +124,32 @@ TEST_CASE_METHOD(
   // Input test data.
   SetInputParam("test", testData);
 
-  mlpackMain();
+  RUN_BINDING();
 
   arma::Row<size_t> predictions;
-  predictions = std::move(IO::GetParam<arma::Row<size_t>>("predictions"));
+  predictions = std::move(params.Get<arma::Row<size_t>>("predictions"));
 
   // Reset passed parameters.
-  IO::GetSingleton().Parameters()["training"].wasPassed = false;
-  IO::GetSingleton().Parameters()["labels"].wasPassed = false;
-  IO::GetSingleton().Parameters()["test"].wasPassed = false;
+  SoftmaxRegression* m = params.Get<SoftmaxRegression*>("output_model");
+  params.Get<SoftmaxRegression*>("output_model") = NULL;
+  CleanMemory();
+  ResetSettings();
 
   // Input trained model.
   SetInputParam("test", std::move(testData));
-  SetInputParam("input_model",
-                IO::GetParam<SoftmaxRegression*>("output_model"));
+  SetInputParam("input_model", m);
 
-  mlpackMain();
+  RUN_BINDING();
 
   // Check that number of output points are equal to number of input points.
-  REQUIRE(IO::GetParam<arma::Row<size_t>>("predictions").n_cols == testSize);
+  REQUIRE(params.Get<arma::Row<size_t>>("predictions").n_cols == testSize);
 
   // Check predictions have only single row.
-  REQUIRE(IO::GetParam<arma::Row<size_t>>("predictions").n_rows == 1);
+  REQUIRE(params.Get<arma::Row<size_t>>("predictions").n_rows == 1);
 
   // Check that initial predictions and final predicitons matrix
   // using saved model are same.
-  CheckMatrices(predictions, IO::GetParam<arma::Row<size_t>>("predictions"));
+  CheckMatrices(predictions, params.Get<arma::Row<size_t>>("predictions"));
 }
 
 /**
@@ -175,7 +157,7 @@ TEST_CASE_METHOD(
  */
 TEST_CASE_METHOD(
     SoftmaxRegressionTestFixture,
-    "SoftmaxRegressionMaxItrTest", "[SoftmaxRegressionMainTest][BindingsTest]")
+    "SoftmaxRegressionMaxItrTest", "[SoftmaxRegressionMainTest][BindingsTests]")
 {
   arma::mat inputData;
   if (!data::Load("trainSet.csv", inputData))
@@ -194,9 +176,7 @@ TEST_CASE_METHOD(
   SetInputParam("labels", std::move(labels));
   SetInputParam("max_iterations", (int) -1);
 
-  Log::Fatal.ignoreInput = true;
-  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 }
 
 /**
@@ -204,7 +184,7 @@ TEST_CASE_METHOD(
  */
 TEST_CASE_METHOD(
     SoftmaxRegressionTestFixture,
-    "SoftmaxRegressionLambdaTest", "[SoftmaxRegressionMainTest][BindingsTest]")
+    "SoftmaxRegressionLambdaTest", "[SoftmaxRegressionMainTest][BindingsTests]")
 {
   arma::mat inputData;
   if (!data::Load("trainSet.csv", inputData))
@@ -223,9 +203,7 @@ TEST_CASE_METHOD(
   SetInputParam("labels", std::move(labels));
   SetInputParam("lambda", (double) -0.1);
 
-  Log::Fatal.ignoreInput = true;
-  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 }
 
 /**
@@ -234,7 +212,7 @@ TEST_CASE_METHOD(
 TEST_CASE_METHOD(
     SoftmaxRegressionTestFixture,
     "SoftmaxRegressionNumClassesTest",
-    "[SoftmaxRegressionMainTest][BindingsTest]")
+    "[SoftmaxRegressionMainTest][BindingsTests]")
 {
   arma::mat inputData;
   if (!data::Load("trainSet.csv", inputData))
@@ -253,9 +231,7 @@ TEST_CASE_METHOD(
   SetInputParam("labels", std::move(labels));
   SetInputParam("number_of_classes", (int) -1);
 
-  Log::Fatal.ignoreInput = true;
-  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 }
 
 /**
@@ -264,7 +240,7 @@ TEST_CASE_METHOD(
 TEST_CASE_METHOD(
     SoftmaxRegressionTestFixture,
     "SoftmaxRegressionTrainingVerTest",
-    "[SoftmaxRegressionMainTest][BindingsTest]")
+    "[SoftmaxRegressionMainTest][BindingsTests]")
 {
   arma::mat inputData;
   if (!data::Load("trainSet.csv", inputData))
@@ -282,15 +258,13 @@ TEST_CASE_METHOD(
   SetInputParam("training", std::move(inputData));
   SetInputParam("labels", std::move(labels));
 
-  mlpackMain();
+  RUN_BINDING();
 
   // Input pre-trained model.
   SetInputParam("input_model",
-                IO::GetParam<SoftmaxRegression*>("output_model"));
+                params.Get<SoftmaxRegression*>("output_model"));
 
-  Log::Fatal.ignoreInput = true;
-  REQUIRE_THROWS_AS(mlpackMain(), std::runtime_error);
-  Log::Fatal.ignoreInput = false;
+  REQUIRE_THROWS_AS(RUN_BINDING(), std::runtime_error);
 }
 
 /**
@@ -300,7 +274,7 @@ TEST_CASE_METHOD(
 TEST_CASE_METHOD(
     SoftmaxRegressionTestFixture,
     "SoftmaxRegressionDiffLambdaTest",
-    "[SoftmaxRegressionMainTest][BindingsTest]")
+    "[SoftmaxRegressionMainTest][BindingsTests]")
 {
   // Train SR for lambda 0.1.
   arma::mat inputData;
@@ -330,18 +304,15 @@ TEST_CASE_METHOD(
   // Input test data.
   SetInputParam("test", testData);
 
-  mlpackMain();
+  RUN_BINDING();
 
   // Store output parameters.
   arma::mat modelParam;
-  modelParam = IO::GetParam<SoftmaxRegression*>("output_model")->Parameters();
-
-  bindings::tests::CleanMemory();
+  modelParam = params.Get<SoftmaxRegression*>("output_model")->Parameters();
 
   // Reset passed parameters.
-  IO::GetSingleton().Parameters()["training"].wasPassed = false;
-  IO::GetSingleton().Parameters()["labels"].wasPassed = false;
-  IO::GetSingleton().Parameters()["test"].wasPassed = false;
+  CleanMemory();
+  ResetSettings();
 
   // Train SR for lamda 0.9.
 
@@ -351,14 +322,14 @@ TEST_CASE_METHOD(
   SetInputParam("lambda", (double) 0.9);
   SetInputParam("test", std::move(testData));
 
-  mlpackMain();
+  RUN_BINDING();
 
   // Check that initial parameters and final parameters matrix
   // using saved model are different.
   for (size_t i = 0; i < modelParam.n_elem; ++i)
   {
     REQUIRE(modelParam[i] !=
-        IO::GetParam<SoftmaxRegression*>("output_model")->Parameters()[i]);
+        params.Get<SoftmaxRegression*>("output_model")->Parameters()[i]);
   }
 }
 
@@ -369,7 +340,7 @@ TEST_CASE_METHOD(
 TEST_CASE_METHOD(
     SoftmaxRegressionTestFixture,
     "SoftmaxRegressionDiffMaxItrTest",
-    "[SoftmaxRegressionMainTest][BindingsTest]")
+    "[SoftmaxRegressionMainTest][BindingsTests]")
 {
   // Train SR for lambda 0.1.
   arma::mat inputData;
@@ -399,18 +370,15 @@ TEST_CASE_METHOD(
   // Input test data.
   SetInputParam("test", testData);
 
-  mlpackMain();
+  RUN_BINDING();
 
   // Store output parameters.
   arma::mat modelParam;
-  modelParam = IO::GetParam<SoftmaxRegression*>("output_model")->Parameters();
-
-  bindings::tests::CleanMemory();
+  modelParam = params.Get<SoftmaxRegression*>("output_model")->Parameters();
 
   // Reset passed parameters.
-  IO::GetSingleton().Parameters()["training"].wasPassed = false;
-  IO::GetSingleton().Parameters()["labels"].wasPassed = false;
-  IO::GetSingleton().Parameters()["test"].wasPassed = false;
+  CleanMemory();
+  ResetSettings();
 
   // Train SR for lamda 0.9.
 
@@ -420,14 +388,14 @@ TEST_CASE_METHOD(
   SetInputParam("max_iterations", (int) 1000);
   SetInputParam("test", std::move(testData));
 
-  mlpackMain();
+  RUN_BINDING();
 
   // Check that initial parameters and final parameters matrix
   // using saved model are different.
   for (size_t i = 0; i < modelParam.n_elem; ++i)
   {
     REQUIRE(modelParam[i] !=
-        IO::GetParam<SoftmaxRegression*>("output_model")->Parameters()[i]);
+        params.Get<SoftmaxRegression*>("output_model")->Parameters()[i]);
   }
 }
 
@@ -438,7 +406,7 @@ TEST_CASE_METHOD(
 TEST_CASE_METHOD(
     SoftmaxRegressionTestFixture,
     "SoftmaxRegressionDiffInterceptTest",
-    "[SoftmaxRegressionMainTest][BindingsTest]")
+    "[SoftmaxRegressionMainTest][BindingsTests]")
 {
   // Train SR with intercept.
   arma::mat inputData;
@@ -468,19 +436,15 @@ TEST_CASE_METHOD(
   // Input test data.
   SetInputParam("test", testData);
 
-  mlpackMain();
+  RUN_BINDING();
 
   // Store output parameters.
   arma::mat modelParam;
-  modelParam = IO::GetParam<SoftmaxRegression*>("output_model")->Parameters();
-
-  bindings::tests::CleanMemory();
+  modelParam = params.Get<SoftmaxRegression*>("output_model")->Parameters();
 
   // Reset passed parameters.
-  IO::GetSingleton().Parameters()["training"].wasPassed = false;
-  IO::GetSingleton().Parameters()["labels"].wasPassed = false;
-  IO::GetSingleton().Parameters()["no_intercept"].wasPassed = false;
-  IO::GetSingleton().Parameters()["test"].wasPassed = false;
+  CleanMemory();
+  ResetSettings();
 
   // Train SR for no_intercept.
 
@@ -489,11 +453,59 @@ TEST_CASE_METHOD(
   SetInputParam("labels", std::move(labels));
   SetInputParam("test", std::move(testData));
 
-  mlpackMain();
+  RUN_BINDING();
 
   // Check that initial parameters has 1 more parameter than
   // final parameters matrix.
   REQUIRE(
-      IO::GetParam<SoftmaxRegression*>("output_model")->Parameters().n_cols ==
+      params.Get<SoftmaxRegression*>("output_model")->Parameters().n_cols ==
       modelParam.n_cols + 1);
 }
+
+/**
+ * Check that we can get output probabilities, and also that they are
+ * reasonable.
+ */
+TEST_CASE_METHOD(
+    SoftmaxRegressionTestFixture,
+    "SoftmaxRegressionProbabilitiesTest",
+    "[SoftmaxRegressionMainTest][BindingsTest]")
+{
+  // Train softmax regression.
+  arma::mat data;
+  if (!data::Load("vc2.csv", data))
+    FAIL("Cannot load train dataset 'vc2.csv'!");
+  // Get the labels out.
+  arma::Row<size_t> labels;
+  if (!data::Load("vc2_labels.txt", labels))
+    FAIL("Cannot load training labels 'vc2_labels.txt'!");
+
+  // Input training data.
+  SetInputParam("training", data);
+  SetInputParam("labels", labels);
+  SetInputParam("no_intercept", (bool) true);
+
+  // Input test data.
+  SetInputParam("test", data);
+
+  RUN_BINDING();
+
+  // Get predictions and probabilities.
+  arma::Row<size_t>& predictions =
+      params.Get<arma::Row<size_t>>("predictions");
+  arma::mat& probabilities = params.Get<arma::mat>("probabilities");
+
+  REQUIRE(predictions.n_elem == probabilities.n_cols);
+  REQUIRE(probabilities.n_rows == arma::max(labels) + 1);
+
+  // Manually compute the predictions and ensure they match, and also check that
+  // the probabilities sum to 1.
+  for (size_t i = 0; i < probabilities.n_cols; ++i)
+  {
+    const double sum = arma::accu(probabilities.col(i));
+    REQUIRE(sum == Approx(1.0));
+
+    size_t classPrediction = (size_t) arma::index_max(probabilities.col(i));
+    REQUIRE(classPrediction == predictions[i]);
+  }
+}
