@@ -10,13 +10,11 @@
  * http://www.opensource.org/licenses/BSD-3-Clause for more information.
  */
 #include <mlpack/core.hpp>
-#include <mlpack/methods/softmax_regression/softmax_regression.hpp>
+#include <mlpack/methods/softmax_regression.hpp>
 
 #include "catch.hpp"
 
 using namespace mlpack;
-using namespace mlpack::regression;
-using namespace mlpack::distribution;
 
 TEST_CASE("SoftmaxRegressionFunctionEvaluate", "[SoftmaxRegressionTest]")
 {
@@ -32,7 +30,7 @@ TEST_CASE("SoftmaxRegressionFunctionEvaluate", "[SoftmaxRegressionTest]")
   // Create random class labels.
   arma::Row<size_t> labels(points);
   for (size_t i = 0; i < points; ++i)
-    labels(i) = math::RandInt(0, numClasses);
+    labels(i) = RandInt(0, numClasses);
 
   // Create a SoftmaxRegressionFunction. Regularization term ignored.
   SoftmaxRegressionFunction srf(data, labels, numClasses, 0);
@@ -79,7 +77,7 @@ TEST_CASE("SoftmaxRegressionFunctionRegularizationEvaluate",
   // Create random class labels.
   arma::Row<size_t> labels(points);
   for (size_t i = 0; i < points; ++i)
-    labels(i) = math::RandInt(0, numClasses);
+    labels(i) = RandInt(0, numClasses);
 
   // 3 objects for comparing regularization costs.
   SoftmaxRegressionFunction srfNoReg(data, labels, numClasses, 0);
@@ -121,7 +119,7 @@ TEST_CASE("SoftmaxRegressionFunctionGradient",
   // Create random class labels.
   arma::Row<size_t> labels(points);
   for (size_t i = 0; i < points; ++i)
-    labels(i) = math::RandInt(0, numClasses);
+    labels(i) = RandInt(0, numClasses);
 
   // 2 objects for 2 terms in the cost function. Each term contributes towards
   // the gradient and thus need to be checked independently.
